local config = require("CraftingFramework.config")
local Util = require("CraftingFramework.util.Util")
local mcmConfig = mwse.loadConfig(config.configPath, config.mcmDefault)

local LINKS_LIST = {
    {
        text = "Historique (VO)",
        url = "https://github.com/jhaakma/crafting-framework/releases"
    },
    {
        text = "Wiki (VO)",
        url = "https://github.com/jhaakma/crafting-framework/wiki"
    },
    {
        text = "Page Nexus",
        url = "https://www.nexusmods.com/morrowind/mods/51009"
    },
    {
        text = "Ko-fi",
        url = "https://ko-fi.com/merlord"
    },
}
local CREDITS_LIST = {
    {
        text = "Par Merlord",
        url = "https://www.nexusmods.com/users/3040468?tab=user+files",
    },
    {
        text = "Effets sonores par SpratlyNation",
        url = "https://www.facebook.com/VideoGame360Pano",
    },
    {
        text = "Aide pour les dfinitions de types par C3pa",
        url = "https://www.nexusmods.com/morrowind/users/37172285"
    }
}
local SIDE_BAR_DEFAULT =
[[Systme d'artisanat est utilis par des mods pour implmenter des mcaniques d'artisanat. Vous pouvez modifier quelques paramtres par dfaut ici, mais la plupart seront propres aux mods et grs par ceux-ci.]]

local function addSideBar(component)
    local versionText = string.format("Crafting Framework")
    component.sidebar:createCategory(versionText)
    component.sidebar:createInfo{ text = SIDE_BAR_DEFAULT}

    local linksCategory = component.sidebar:createCategory("Links")
    for _, link in ipairs(LINKS_LIST) do
        linksCategory:createHyperLink{ text = link.text, url = link.url }
    end
    local creditsCategory = component.sidebar:createCategory("Crdits")
    for _, credit in ipairs(CREDITS_LIST) do
        creditsCategory:createHyperLink{ text = credit.text, url = credit.url }
    end
end


local function registerMCM()
    local template = mwse.mcm.createTemplate{ name = config.static.modName }
    template.onClose = function()
        config.save(mcmConfig)
    end
    template:register()

    local page = template:createSideBarPage{ label = "Paramtres"}
    addSideBar(page)
    page:createDropdown{
        label = "Niveau de journalisation",
        description = "Dfinit le niveau de journalisation du mod pour le fichier mwse.log. Laissez-le sur INFO  moins que vous n'ayez besoin de faire du dbuggage.",
        options = {
            { label = "TRACE", value = "TRACE"},
            { label = "DEBUG", value = "DEBUG"},
            { label = "INFO", value = "INFO"},
            { label = "ERROR", value = "ERROR"},
            { label = "NONE", value = "NONE"},
        },
        variable =  mwse.mcm.createTableVariable{ id = "logLevel", table = mcmConfig },
        callback = function(self)
            for _, logger in pairs(Util.loggers) do
                logger:setLogLevel(self.variable.value)
                ---@diagnostic disable-next-line
                logger:info("New Log Level: %s", logger.logLevel)
            end
        end
    }

    page:createSlider{
        label = "Rcupration de matriaux : %s %%",
        description = "Dfinit le pourcentage de matriaux rcuprs lorsqu'un objet fabriqu est dtruit. Certains mods ou recettes peuvent avoir leurs propres dfinitions de cette valeur. Par dfaut : 75 %",
        min = 0,
        max = 100,
        step = 1,
        variable = mwse.mcm.createTableVariable{ id = "defaultMaterialRecovery", table = mcmConfig },
    }

    page:createKeyBinder{
        label = "Assigner raccourci pour QuickActivate",
        description = "Touche modificatrice pour les recettes enregistres avec un `quickActivateCallback`. Par dfaut : Maj gauche",
        allowCombinations = false,
        variable = mwse.mcm.createTableVariable{ id = "quickModifierHotkey", table = mcmConfig },
    }

    page:createYesNoButton{
        label = "Activer le stockage infini",
        description = "Activez cette option pour permettre aux conteneurs de contenir une quantit infinie d'objets. N'affectera pas les conteneurs prcdemment placs.",
        variable = mwse.mcm.createTableVariable{ id = "enableInfiniteStorage", table = config.mcm },
    }
end
event.register("modConfigReady", registerMCM)
